@@ -1,6 +1,6 @@
 use {
-    crate::{state::*, errors::ErrorCode},
-    anchor_lang::{prelude::*},
+    crate::{errors::ErrorCode, state::*},
+    anchor_lang::prelude::*,
 };
 
 #[derive(Accounts)]
@@ -10,16 +10,16 @@ pub struct AddInvalidatorCtx<'info> {
 
     // issuer
     #[account(mut, constraint = issuer.key() == token_manager.issuer @ ErrorCode::InvalidIssuer)]
-    issuer: Signer<'info>
+    issuer: Signer<'info>,
 }
 
 pub fn handler(ctx: Context<AddInvalidatorCtx>, invalidator: Pubkey) -> Result<()> {
     // set token manager data
     let token_manager = &mut ctx.accounts.token_manager;
     if token_manager.invalidators.len() as u8 >= token_manager.num_invalidators {
-        return Err(error!(ErrorCode::InvalidIssuerTokenAccount));
+        return Err(error!(ErrorCode::MaximumInvalidatorsReached));
     }
 
     token_manager.invalidators.push(invalidator);
-    return Ok(())
-}
\ No newline at end of file
+    Ok(())
+}
